
From: Kumar Gala <galak@freescale.com>

Moved reporting of chipset revision from board specific to common handing
of /proc/cpuinfo.  In light of numerous PPC system-on-chip devices, we
report both the cpu version (reflects the core version) and the chipset
version (reflects the system-on-chip or bridge version).

Signed-off-by: Kumar Gala <kumar.gala@freescale.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/ppc/kernel/setup.c                      |    7 +++++++
 25-akpm/arch/ppc/platforms/83xx/mpc834x_sys.c        |    1 -
 25-akpm/arch/ppc/platforms/85xx/mpc85xx_ads_common.c |    1 -
 25-akpm/arch/ppc/platforms/85xx/mpc85xx_cds_common.c |    1 -
 25-akpm/arch/ppc/platforms/85xx/sbc85xx.c            |    1 -
 25-akpm/arch/ppc/platforms/85xx/stx_gp3.c            |    1 -
 6 files changed, 7 insertions(+), 5 deletions(-)

diff -puN arch/ppc/kernel/setup.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling arch/ppc/kernel/setup.c
--- 25/arch/ppc/kernel/setup.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling	2005-03-21 23:01:22.000000000 -0800
+++ 25-akpm/arch/ppc/kernel/setup.c	2005-03-21 23:01:22.000000000 -0800
@@ -40,6 +40,7 @@
 #include <asm/nvram.h>
 #include <asm/xmon.h>
 #include <asm/ocp.h>
+#include <asm/ppc_sys.h>
 
 #if defined CONFIG_KGDB
 #include <asm/kgdb.h>
@@ -246,6 +247,12 @@ int show_cpuinfo(struct seq_file *m, voi
 	seq_printf(m, "bogomips\t: %lu.%02lu\n",
 		   lpj / (500000/HZ), (lpj / (5000/HZ)) % 100);
 
+#if defined (CONFIG_85xx) || defined (CONFIG_83xx)
+	if (cur_ppc_sys_spec->ppc_sys_name)
+		seq_printf(m, "chipset\t\t: %s\n",
+			cur_ppc_sys_spec->ppc_sys_name);
+#endif
+
 #ifdef CONFIG_SMP
 	seq_printf(m, "\n");
 #endif
diff -puN arch/ppc/platforms/83xx/mpc834x_sys.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling arch/ppc/platforms/83xx/mpc834x_sys.c
--- 25/arch/ppc/platforms/83xx/mpc834x_sys.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling	2005-03-21 23:01:22.000000000 -0800
+++ 25-akpm/arch/ppc/platforms/83xx/mpc834x_sys.c	2005-03-21 23:01:22.000000000 -0800
@@ -143,7 +143,6 @@ mpc834x_sys_show_cpuinfo(struct seq_file
 	pvid = mfspr(SPRN_PVR);
 	svid = mfspr(SPRN_SVR);
 
-	seq_printf(m, "chip\t\t: MPC%s\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "Vendor\t\t: Freescale Inc.\n");
 	seq_printf(m, "Machine\t\t: mpc%s sys\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "core clock\t: %d MHz\n"
diff -puN arch/ppc/platforms/85xx/mpc85xx_ads_common.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling arch/ppc/platforms/85xx/mpc85xx_ads_common.c
--- 25/arch/ppc/platforms/85xx/mpc85xx_ads_common.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling	2005-03-21 23:01:22.000000000 -0800
+++ 25-akpm/arch/ppc/platforms/85xx/mpc85xx_ads_common.c	2005-03-21 23:01:22.000000000 -0800
@@ -129,7 +129,6 @@ mpc85xx_ads_show_cpuinfo(struct seq_file
 	pvid = mfspr(SPRN_PVR);
 	svid = mfspr(SPRN_SVR);
 
-	seq_printf(m, "chip\t\t: MPC%s\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "Vendor\t\t: Freescale Semiconductor\n");
 	seq_printf(m, "Machine\t\t: mpc%sads\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "clock\t\t: %dMHz\n", freq / 1000000);
diff -puN arch/ppc/platforms/85xx/mpc85xx_cds_common.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling arch/ppc/platforms/85xx/mpc85xx_cds_common.c
--- 25/arch/ppc/platforms/85xx/mpc85xx_cds_common.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling	2005-03-21 23:01:22.000000000 -0800
+++ 25-akpm/arch/ppc/platforms/85xx/mpc85xx_cds_common.c	2005-03-21 23:01:22.000000000 -0800
@@ -146,7 +146,6 @@ mpc85xx_cds_show_cpuinfo(struct seq_file
 	pvid = mfspr(SPRN_PVR);
 	svid = mfspr(SPRN_SVR);
 
-	seq_printf(m, "chip\t\t: MPC%s\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "Vendor\t\t: Freescale Semiconductor\n");
 	seq_printf(m, "Machine\t\t: CDS - MPC%s (%x)\n", cur_ppc_sys_spec->ppc_sys_name, cadmus[CM_VER]);
 	seq_printf(m, "clock\t\t: %dMHz\n", freq / 1000000);
diff -puN arch/ppc/platforms/85xx/sbc85xx.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling arch/ppc/platforms/85xx/sbc85xx.c
--- 25/arch/ppc/platforms/85xx/sbc85xx.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling	2005-03-21 23:01:22.000000000 -0800
+++ 25-akpm/arch/ppc/platforms/85xx/sbc85xx.c	2005-03-21 23:01:22.000000000 -0800
@@ -129,7 +129,6 @@ sbc8560_show_cpuinfo(struct seq_file *m)
 	pvid = mfspr(SPRN_PVR);
 	svid = mfspr(SPRN_SVR);
 
-	seq_printf(m, "chip\t\t: MPC%s\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "Vendor\t\t: Wind River\n");
 	seq_printf(m, "Machine\t\t: SBC%s\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "clock\t\t: %dMHz\n", freq / 1000000);
diff -puN arch/ppc/platforms/85xx/stx_gp3.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling arch/ppc/platforms/85xx/stx_gp3.c
--- 25/arch/ppc/platforms/85xx/stx_gp3.c~ppc32-report-chipset-version-in-common-proc-cpuinfo-handling	2005-03-21 23:01:22.000000000 -0800
+++ 25-akpm/arch/ppc/platforms/85xx/stx_gp3.c	2005-03-21 23:01:22.000000000 -0800
@@ -268,7 +268,6 @@ gp3_show_cpuinfo(struct seq_file *m)
 
 	memsize = total_memory;
 
-	seq_printf(m, "chip\t\t: MPC%s\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "Vendor\t\t: RPC Electronics STx \n");
 	seq_printf(m, "Machine\t\t: GP3 - MPC%s\n", cur_ppc_sys_spec->ppc_sys_name);
 	seq_printf(m, "bus freq\t: %u.%.6u MHz\n", freq / 1000000,
_
